[![pypi](https://img.shields.io/badge/pypi-aiotgm-blue)](https://pypi.org/project/aiotgm/) [![tele](https://img.shields.io/badge/telegram-@geko1-blue)](https://t.me/geko1) [![Documentation Status](https://readthedocs.org/projects/aiotgm/badge/?version=latest)](https://aiotgm.readthedocs.io/?badge=latest)

<h3 align="center">Asynchronous python implementation of the Telegram Bot API <a href="https://core.telegram.org/bots/api#august-14-2024">7.9</a></h3>

#

* #### Prerequisites
You require a good python knowledge with the [asyncio module](https://docs.python.org/3/library/asyncio.html) and a Telegram Bot API token, you can get it via [@BotFather](https://t.me/botfather).

#

* #### Dependencies
  * Python >= 3.8
  * [aiohttp](https://github.com/aio-libs/aiohttp)
  * Optional [ujson](https://github.com/ultrajson/ultrajson) & [certifi](https://github.com/certifi/python-certifi)

#

* #### Installation

Install the module using [pip](https://pypi.org/project/aiotgm/) with your shell.

```powershell
$ pip install aiotgm
```

Update the module regurarly with the following command.

```powershell
$ pip install -U aiotgm
```

#

* #### Documentation
Here it is the [official documentation](https://aiotgm.readthedocs.io/).
